//--------------------------------------------------------------------------------
// ********* Fleatiny-FPGA V2.5 Platform VERILOG top-level module ***********
// This is basically a wrapper allows connection of user projects to 
// Fleatiny-FPGA's on-board hardware
//
// Creation Date: 20th October 2014
// Author: Valentin Angelovski
//
// 2013-2014 - Valentin Angelovski
//--------------------------------------------------------------------------------


module FleaFPGA_2v5(
//    -- System clock and reset
	input sys_clock, // main clock input from external clock source
	input sys_reset, // main clock input from external RC reset circuit

//    -- On-board user buttons and status LEDs
	input n_pb1,  
	input n_pb2,
	output n_led1,
	output n_led2,
	output n_led3,
	output n_led4,

//    -- USB Host (CH376T) interface
	output host_reset,
	output host_spi,
	input host_nInt,
	output host_sdi,
	input host_sdo,
	output host_sck,
	output host_cs,
	output host_tx_o,
	input host_rx_i,

	
//    -- USB Slave (FT230x) interface 
	output slave_tx_o,
	input slave_rx_i,

//    -- User GPIO (18 I/O pins) Header
	inout [18:1]GPIO,  // GPIO Header pins available as one data block
	
//	-- SDRAM interface (For use with 16Mx16bit or 32Mx16bit SDR DRAM, depending on version)
	output Dram_Clk,	// clock to SDRAM
	output Dram_n_Ras,  // SDRAM RAS
	output Dram_n_Cas,	// SDRAM CAS
	output Dram_n_We,	// SDRAM write-enable
	output [1:0]Dram_BA,	// SDRAM bank-address
	output [12:0]Dram_Addr,	// SDRAM address bus
	inout [15:0]Dram_Data,	// data bus to/from SDRAM
	output Dram_n_cs, 
	output Dram_DQMH,
	output Dram_DQML,
	
//	-- VGA interface (Note: 12-bit color organized as RGB = 4/4/4-bits)
	output vga_vs,
	output vga_hs,
	output [3:0]vga_red,
	output [3:0]vga_green,
	output [3:0]vga_blue,
	
//	-- SD/MMC Interface (Support either SPI or nibble-mode)
	input mmc_dat1,
	input mmc_dat2,
	output mmc_n_cs,
	output mmc_clk,
	output mmc_mosi,
	input mmc_miso,

//	-- SPI SRAM (SPI-only for now..)
	inout spi_sram_cs,
	inout spi_sram_hold,
	inout spi_sram_clk,
	inout spi_sram_miso,
	inout spi_sram_mosi,

//	-- Audio out (stereo-PWM) interface	
	output Audio_l,
	output Audio_r,
	
//	-- PS2 interface (Both ports accessible via Y-splitter cable)
	inout PS2_clk1,
	inout PS2_data1,
	inout PS2_clk2,
	inout PS2_data2
    );
	
//  -- Housekeeping logic for unwanted peripherals on FleaFPGA board goes here!!!
//  -- (Note: comment out any of the following code lines if peripheral is required)
	wire [3:0]LED;
	assign host_cs = 1'b1; 	// -- USB host SPI interface disabled
	assign {n_led4, n_led3, n_led2, n_led1} = ~LED;

	system my_system
	(
		//.CLK_50MHZ(sys_clock),

		//.BTN_RESET(!n_pb1)
	);
 
endmodule
